function [t, y] = strangaut(y0, t0, T, h)
% Strang splitting method for the solution of an autonomized IVP
%
% Input:
% y0: initial value
% t0: initial time
% T: end time
% h: step size
%
% output:
% t: time grid
% y: solution at the points of the grid

% initialization
A0 = [0, 1; -1, 0];

% adapt step size, so that end time is attained precisely
N = ceil((T-t0) / h);
h = (T-t0) / N;

% allocate memory for results
t = zeros(N+1, 1);
y = zeros(2, N+1);

% set starting values
t(1) = t0;
y(:, 1) = y0;

% Timestepping
for k = 1:N
	
	% apply Strang splitting method
	
	y0 = expm(h * (t0 + 0.5*h) * A0) * y0;
	t0 = t0 + h;
	% save results
	t(k+1) = t0;
	y(:, k+1) = y0;
end
